Class PropertyContainer
- All Implemented Interfaces:
Serializable,Cloneable
- Direct Known Subclasses:
EmbeddedEntity,Entity
- See Also:
-
Method Summary
Modifier and TypeMethodDescriptionGets all of the properties belonging to this container.@Nullable ObjectgetProperty(String propertyName) Gets the property with the specified name.booleanhasProperty(String propertyName) Returns true if a property has been set.booleanisUnindexedProperty(String propertyName) Returns true ifpropertyNamehas a value that will not be indexed.voidremoveProperty(String propertyName) Removes any property with the specified name.voidsetIndexedProperty(String propertyName, Object value) Like {link #setProperty}, but requires that the value is indexable or a collection of indexable values.voidA convenience method that populates properties from those in the given container.voidsetProperty(String propertyName, @Nullable Object value) Sets the property named,propertyName, tovalue.voidsetUnindexedProperty(String propertyName, Object value) Like#setProperty, but doesn't index the property in the built-in single property indexes or the user-defined composite indexes.
-
Method Details
-
getProperty
Gets the property with the specified name. The value returned may not be the same type as originally set viasetProperty(java.lang.String, java.lang.Object).- Returns:
- the property corresponding to
propertyName.
-
getProperties
Gets all of the properties belonging to this container.- Returns:
- an unmodifiable
Mapof properties.
-
hasProperty
Returns true if a property has been set. If a property has been explicitly set tonull, this function will return true.- Returns:
- true iff the property named
propertyNameexists.
-
removeProperty
Removes any property with the specified name. If there is no property with this name set, simply does nothing.- Throws:
NullPointerException- IfpropertyNameis null.
-
setProperty
Sets the property named,propertyName, tovalue.As the value is stored in the datastore, it is converted to the datastore's native type. This may include widening, such as converting a
Shortto aLong.If value is a
Collection, the values will be stored in the datastore with the collection's iteration order with one caveat: all indexed values will come before all unindexed values (this can occur if theCollectioncontains both values that are normally indexed like strings, and values that are never indexed likeBlob,TextandEmbeddedEntity).Overrides any existing value for this property, whether indexed or unindexed.
Note that
Blob,TextandEmbeddedEntityproperty values are never indexed. To store other types without being indexed, usesetUnindexedProperty(java.lang.String, java.lang.Object).- Parameters:
value- may be one of the supported datatypes or a heterogeneousCollectionof one of the supported datatypes.- Throws:
IllegalArgumentException- If the value is not of a type that the data store supports.- See Also:
-
setIndexedProperty
Like {link #setProperty}, but requires that the value is indexable or a collection of indexable values. -
setUnindexedProperty
Like#setProperty, but doesn't index the property in the built-in single property indexes or the user-defined composite indexes.- Parameters:
value- may be one of the supported datatypes, or a heterogeneousCollectionof one of the supported datatypes.Overrides any existing value for this property, whether indexed or unindexed.
- Throws:
IllegalArgumentException- If the value is not of a type that the data store supports.- See Also:
-
isUnindexedProperty
Returns true ifpropertyNamehas a value that will not be indexed. This includesText,Blob, and any property added usingsetUnindexedProperty(java.lang.String, java.lang.Object).Note: The behavior of this method is not well defined in case of an indexed property whose value is a list that contains unindexable values.
-
setPropertiesFrom
A convenience method that populates properties from those in the given container.This method transfers information about unindexed properties and clones any mutable values.
- Parameters:
src- The container from which we will populate ourself.
-