Class PropertyProjection
java.lang.Object
com.google.appengine.api.datastore.Projection
com.google.appengine.api.datastore.PropertyProjection
- All Implemented Interfaces:
Serializable
A property projection.
If specified on a query, this will cause the query return the specified property.
- See Also:
-
Constructor Summary
ConstructorsConstructorDescriptionPropertyProjection(String propertyName, @Nullable Class<?> type) Constructs a property projection. -
Method Summary
-
Constructor Details
-
PropertyProjection
Constructs a property projection.If type is specified,
RawValue.asType(Class)will be used to restore the original value of the property. Otherwise instances ofRawValuewill be returned.- Parameters:
propertyName- The name of the property to projecttype- The type of values stored in the projected properties ornullif the type is not known or variable. Ifnull,RawValuesare returned.
-
-
Method Details
-
getName
Description copied from class:ProjectionReturns the name of the property this projection populates.- Specified by:
getNamein classProjection
-
getType
Returns the type specified for this projection. -
toString
-
hashCode
public int hashCode() -
equals
-