Uses of Class
com.google.appengine.api.datastore.KeyRange
Packages that use KeyRange
Package
Description
-
Uses of KeyRange in com.google.appengine.api.datastore
Methods in com.google.appengine.api.datastore that return KeyRangeModifier and TypeMethodDescriptionDatastoreService.allocateIds(Key parent, String kind, long num) IDs are allocated within a namespace defined by a parent key and a kind.DatastoreService.allocateIds(String kind, long num) IDs are allocated within a namespace defined by a parent key and a kind.Methods in com.google.appengine.api.datastore that return types with arguments of type KeyRangeModifier and TypeMethodDescriptionAdminDatastoreService.allocateIds(@Nullable Key parent, String kind, long num) AdminDatastoreService.allocateIds(String kind, long num) AsyncDatastoreService.allocateIds(@Nullable Key parent, String kind, long num) AsyncDatastoreService.allocateIds(String kind, long num) Methods in com.google.appengine.api.datastore with parameters of type KeyRangeModifier and TypeMethodDescriptionDatastoreService.allocateIdRange(KeyRange range) This method allocates a user-specified contiguous range of unique IDs.