Class AppLogLine

java.lang.Object
com.google.appengine.api.log.AppLogLine
All Implemented Interfaces:
Serializable

public final class AppLogLine extends Object implements Serializable
An AppLogLine contains all the information for a single application log. Specifically, this information is: (1) the time at which the logged event occurred, (2) the level that the event was logged at, and (3) the message associated with this event. AppLogLines may be inserted by the user via logging frameworks, or by App Engine itself if we wish to alert the user that certain events have occurred.
See Also:
  • Constructor Details

    • AppLogLine

      public AppLogLine()
      Default zero-argument constructor that creates an AppLogLine.
  • Method Details

    • getLogLevel

      public LogService.LogLevel getLogLevel()
    • getLogMessage

      public String getLogMessage()
    • getTimeUsec

      public long getTimeUsec()
    • setLogLevel

      public void setLogLevel(LogService.LogLevel logLevel)
    • setLogMessage

      public void setLogMessage(String logMessage)
    • setTimeUsec

      public void setTimeUsec(long timeUsec)
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public boolean equals(@Nullable Object obj)
      Overrides:
      equals in class Object