Class LogQuery.Builder

java.lang.Object
com.google.appengine.api.log.LogQuery.Builder
Enclosing class:
LogQuery

public static final class LogQuery.Builder extends Object
Contains static creation methods for LogQuery.
  • Constructor Details

    • Builder

      public Builder()
  • Method Details

    • withOffset

      public static LogQuery withOffset(String offset)
      Create a LogQuery with the given offset. Shorthand for LogQuery.Builder.withDefaults().offset(offset);. Please read the LogQuery class javadoc for an explanation of how offsets are used.
      Parameters:
      offset - the offset to use.
      Returns:
      The newly created LogQuery instance.
    • withStartTimeMillis

      public static LogQuery withStartTimeMillis(long startTimeMillis)
      Create a LogQuery with the given start time. Shorthand for LogQuery.Builder.withDefaults().startTimeMillis(startTimeMillis);. Please read the LogQuery class javadoc for an explanation of how start time is used.
      Parameters:
      startTimeMillis - the start time to use, in milliseconds.
      Returns:
      The newly created LogQuery instance.
    • withStartTimeUsec

      public static LogQuery withStartTimeUsec(long startTimeUsec)
      Create a LogQuery with the given start time. Shorthand for LogQuery.Builder.withDefaults().startTimeUsec(startTimeUsec);. Please read the LogQuery class javadoc for an explanation of how start time is used.
      Parameters:
      startTimeUsec - the start time to use, in microseconds.
      Returns:
      The newly created LogQuery instance.
    • withEndTimeMillis

      public static LogQuery withEndTimeMillis(long endTimeMillis)
      Create a LogQuery with the given end time. Shorthand for LogQuery.Builder.withDefaults().endTimeMillis(endTimeMillis);. Please read the LogQuery class javadoc for an explanation of how end time is used.
      Parameters:
      endTimeMillis - the end time to use, in milliseconds.
      Returns:
      The newly created LogQuery instance.
    • withEndTimeUsec

      public static LogQuery withEndTimeUsec(long endTimeUsec)
      Create a LogQuery with the given end time. Shorthand for LogQuery.Builder.withDefaults().endTimeUsec(endTimeUsec);. Please read the LogQuery class javadoc for an explanation of how end time is used.
      Parameters:
      endTimeUsec - the start time to use, in microseconds.
      Returns:
      The newly created LogQuery instance.
    • withBatchSize

      public static LogQuery withBatchSize(int batchSize)
      Create a LogQuery with the given batch size. Shorthand for LogQuery.Builder.withDefaults().batchSize(batchSize);. Please read the LogQuery class javadoc for an explanation of how batch size is used.
      Parameters:
      batchSize - the batch size to set.
      Returns:
      The newly created LogQuery instance.
    • withMinLogLevel

      public static LogQuery withMinLogLevel(LogService.LogLevel minLogLevel)
      Create a LogQuery with the given minimum log level. Shorthand for LogQuery.Builder.withDefaults().minLogLevel(minLogLevel);. Please read the LogQuery class javadoc for an explanation of how minimum log level is used.
      Parameters:
      minLogLevel - the minimum log level to set.
      Returns:
      The newly created LogQuery instance.
    • withIncludeIncomplete

      public static LogQuery withIncludeIncomplete(boolean includeIncomplete)
      Create a LogQuery with the given include incomplete setting. Shorthand for LogQuery.Builder.withDefaults().includeIncomplete(includeIncomplete);. Please read the LogQuery class javadoc for an explanation of how include incomplete is used.
      Parameters:
      includeIncomplete - the inclusion value to set.
      Returns:
      The newly created LogQuery instance.
    • withIncludeAppLogs

      public static LogQuery withIncludeAppLogs(boolean includeAppLogs)
      Create a LogQuery with include application logs set. Shorthand for LogQuery.Builder.withDefaults().includeAppLogs(includeAppLogs);. Please read the LogQuery class javadoc for an explanation of the include application logs setting.
      Parameters:
      includeAppLogs - the inclusion value to set.
      Returns:
      The newly created LogQuery instance.
    • withMajorVersionIds

      public static LogQuery withMajorVersionIds(List<String> versionIds)
      Create a LogQuery with the given major version IDs. Shorthand for LogQuery.Builder.withDefaults().majorVersionIds(versionIds);. Please read the LogQuery class javadoc for an explanation of how the list of major version ids is used.
      Parameters:
      versionIds - the major version id list to set.
      Returns:
      The newly created LogQuery instance.
    • withVersions

      public static LogQuery withVersions(List<LogQuery.Version> versions)
      Create a LogQuery with the given LogQuery.Version values. Shorthand for LogQuery.Builder.withDefaults().versions(versions);. Please read the LogQuery class javadoc for usage information.
      Parameters:
      versions - the list to set.
      Returns:
      The newly created LogQuery instance.
    • withRequestIds

      public static LogQuery withRequestIds(List<String> requestIds)
      Create a LogQuery with the given request IDs. Shorthand for LogQuery.Builder.withDefaults().requestIds(requestIds);. See the LogQuery class javadoc for an explanation of how the list of request ids is used.
      Parameters:
      requestIds - the request id list to set.
      Returns:
      The newly created LogQuery instance.
      Since:
      App Engine 1.7.4.
    • withDefaults

      public static LogQuery withDefaults()
      Helper method for creating a LogQuery instance with default values. Please read the LogQuery class javadoc for an explanation of the defaults.