Uses of Class
com.google.appengine.api.log.LogQuery
Packages that use LogQuery
Package
Description
Provides access to request logs and application logs.
-
Uses of LogQuery in com.google.appengine.api.log
Methods in com.google.appengine.api.log that return LogQueryModifier and TypeMethodDescriptionLogQuery.batchSize(int batchSize) Sets the batch size.LogQuery.clone()Makes a copy of a provided LogQuery.LogQuery.endTimeMillis(long endTimeMillis) Sets the end time to a value in milliseconds.LogQuery.endTimeUsec(long endTimeUsec) Sets the end time to a value in microseconds.LogQuery.includeAppLogs(boolean includeAppLogs) Sets include application logs.LogQuery.includeIncomplete(boolean includeIncomplete) Sets include incomplete.LogQuery.majorVersionIds(List<String> versionIds) Sets the major version identifiers to query.LogQuery.minLogLevel(LogService.LogLevel minLogLevel) Sets the minimum log level.Sets the offset.LogQuery.requestIds(List<String> requestIds) Sets the list of request ids to query.LogQuery.startTimeMillis(long startTimeMillis) Sets the start time to a value in milliseconds.LogQuery.startTimeUsec(long startTimeUsec) Sets the start time to a value in microseconds.LogQuery.versions(List<LogQuery.Version> versions) Restricts the query to log records for the specified module versions.static LogQueryLogQuery.Builder.withBatchSize(int batchSize) Create aLogQuerywith the given batch size.static LogQueryLogQuery.Builder.withDefaults()Helper method for creating aLogQueryinstance with default values.static LogQueryLogQuery.Builder.withEndTimeMillis(long endTimeMillis) Create aLogQuerywith the given end time.static LogQueryLogQuery.Builder.withEndTimeUsec(long endTimeUsec) Create aLogQuerywith the given end time.static LogQueryLogQuery.Builder.withIncludeAppLogs(boolean includeAppLogs) Create aLogQuerywith include application logs set.static LogQueryLogQuery.Builder.withIncludeIncomplete(boolean includeIncomplete) Create aLogQuerywith the given include incomplete setting.static LogQueryLogQuery.Builder.withMajorVersionIds(List<String> versionIds) Create aLogQuerywith the given major version IDs.static LogQueryLogQuery.Builder.withMinLogLevel(LogService.LogLevel minLogLevel) Create aLogQuerywith the given minimum log level.static LogQueryLogQuery.Builder.withOffset(String offset) Create aLogQuerywith the given offset.static LogQueryLogQuery.Builder.withRequestIds(List<String> requestIds) Create aLogQuerywith the given request IDs.static LogQueryLogQuery.Builder.withStartTimeMillis(long startTimeMillis) Create aLogQuerywith the given start time.static LogQueryLogQuery.Builder.withStartTimeUsec(long startTimeUsec) Create aLogQuerywith the given start time.static LogQueryLogQuery.Builder.withVersions(List<LogQuery.Version> versions) Create aLogQuerywith the givenLogQuery.Versionvalues.Methods in com.google.appengine.api.log with parameters of type LogQueryModifier and TypeMethodDescriptionRetrieve logs for the current application with the constraints provided by the user as parameters to this function.