Interface Stats


public interface Stats
Statistics from the cache, available via MemcacheService.getStatistics()
  • Method Details

    • getHitCount

      long getHitCount()
      The counter of "successful" MemcacheService.get(Object) or MemcacheService.contains(Object) operations.
    • getMissCount

      long getMissCount()
      The counter of "unsuccessful" MemcacheService.get(Object) or MemcacheService.contains(Object) operations.
    • getBytesReturnedForHits

      long getBytesReturnedForHits()
      Sum of key and value bytes in successful get() and contains().
    • getItemCount

      long getItemCount()
      Number of entries currently "alive" in the cache.
    • getTotalItemBytes

      long getTotalItemBytes()
      Sum of key and value sizes for all live entries currently in cache.
    • getMaxTimeWithoutAccess

      int getMaxTimeWithoutAccess()
      Milliseconds since last access of least-recently-used live entry.