Uses of Interface
com.google.appengine.api.memcache.ErrorHandler
Packages that use ErrorHandler
Package
Description
Provides fast but unreliable data storage, also accessible via a JCache interface.
-
Uses of ErrorHandler in com.google.appengine.api.memcache
Subinterfaces of ErrorHandler in com.google.appengine.api.memcacheModifier and TypeInterfaceDescriptioninterfaceA marker interface to indicate that allMemcacheServiceExceptionexceptions should be handled byhandleServiceError(MemcacheServiceException).Classes in com.google.appengine.api.memcache that implement ErrorHandlerModifier and TypeClassDescriptionclassSimilar to the deprecatedLogAndContinueErrorHandlerbut consistently handles all back-end related errors.classThe default error handler, which will cause most service errors to behave as though there were a cache miss, not an error.classA strict error handler, which will throwMemcacheServiceExceptionorInvalidValueExceptionfor any service error condition.Methods in com.google.appengine.api.memcache that return ErrorHandlerModifier and TypeMethodDescriptionstatic ErrorHandlerErrorHandlers.getDefault()Returns the default error handler.BaseMemcacheService.getErrorHandler()Fetches the current error handler.Methods in com.google.appengine.api.memcache with parameters of type ErrorHandlerModifier and TypeMethodDescriptionvoidBaseMemcacheService.setErrorHandler(ErrorHandler handler) Registers a newErrorHandler.