Uses of Enum Class
com.google.appengine.api.memcache.MemcacheSerialization.Flag
Packages that use MemcacheSerialization.Flag
Package
Description
Provides fast but unreliable data storage, also accessible via a JCache interface.
-
Uses of MemcacheSerialization.Flag in com.google.appengine.api.memcache
Fields in com.google.appengine.api.memcache declared as MemcacheSerialization.FlagMethods in com.google.appengine.api.memcache that return MemcacheSerialization.FlagModifier and TypeMethodDescriptionstatic MemcacheSerialization.FlagMemcacheSerialization.Flag.fromInt(int i) While the enum is convenient, the implementation wantsints...static MemcacheSerialization.FlagReturns the enum constant of this class with the specified name.static MemcacheSerialization.Flag[]MemcacheSerialization.Flag.values()Returns an array containing the constants of this enum class, in the order they are declared.