Uses of Class
com.google.appengine.api.memcache.MemcacheServiceException
Packages that use MemcacheServiceException
Package
Description
Provides fast but unreliable data storage, also accessible via a JCache interface.
-
Uses of MemcacheServiceException in com.google.appengine.api.memcache
Methods in com.google.appengine.api.memcache with parameters of type MemcacheServiceExceptionModifier and TypeMethodDescriptionvoidConsistentErrorHandler.handleServiceError(MemcacheServiceException ex) voidErrorHandler.handleServiceError(MemcacheServiceException ex) Handles back-end service errors.voidLogAndContinueErrorHandler.handleServiceError(MemcacheServiceException thrown) Logs thethrownerror condition, but does not expose it to application code.voidStrictErrorHandler.handleServiceError(MemcacheServiceException t) ThrowsMemcacheServiceExceptionfor any call.