Package com.google.appengine.api.modules
package com.google.appengine.api.modules
Utility functions for working with App Engine services (previously known as modules).
A common pattern of usage is:
// Get a handle of the ModulesService.
ModulesService modules = ModulesServiceFactory.getModulesService();
// Lookup the versions associated with the current service/module.
for (String version : modules.getVersions(modules.getCurrentModule())) {
// Process version.
}
- See Also:
-
ClassDescriptionFactory interface for use by providers of
ModulesServicefor registration withServiceFactoryFactory.Google App Engine'sFactoryProviderforIModulesServiceFactory.Exception thrown by theModulesService.ModulesService allows the application to fetch information about its own module and version information.Factory by which users get an implementation of theModulesService.