Class SortOptions

java.lang.Object
com.google.appengine.api.search.SortOptions

public final class SortOptions extends Object
Definition of how to sort documents. You may specify zero or more sort expressions and set a match scorer. If you have a large index, it is advisable to set a limit.
  • Method Details

    • getSortExpressions

      public List<SortExpression> getSortExpressions()
      Returns:
      a list of sort expressions representing a multi-dimensional sort
    • getMatchScorer

      public MatchScorer getMatchScorer()
      Returns:
      a MatchScorer used to score the documents
    • getLimit

      public int getLimit()
      Returns:
      the limit on the number of documents to score or sort
    • newBuilder

      public static SortOptions.Builder newBuilder()
      Creates and returns a SortOptions Builder.
      Returns:
      a new SortOptions.Builder. Set the parameters for SortOptions on the Builder, and use the SortOptions.Builder.build() method to create a concrete instance of SortOptions
    • toString

      public String toString()
      Overrides:
      toString in class Object