Class DeferredTaskContext
java.lang.Object
com.google.appengine.api.taskqueue.ee10.DeferredTaskContext
Resources for managing
.
invalid reference
DeferredTask
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionstatic jakarta.servlet.http.HttpServletRequestReturns theHttpServletRequestinstance for the current running deferred task for the current thread ornullif there is no current deferred task active for this thread.static jakarta.servlet.http.HttpServletResponseReturns theHttpServletResponseinstance for the current running deferred task for the current thread ornullif there is no current deferred task active for this thread.static jakarta.servlet.http.HttpServletReturns theHttpServletinstance for the current running deferred task for the current thread ornullif there is no current deferred task active for this thread.static voidRequest a retry of this task, even if an exception was not thrown.static voidsetDoNotRetry(boolean value) Sets the action on task failure.
-
Field Details
-
RUNNABLE_TASK_CONTENT_TYPE
The content type of a serialized.invalid reference
DeferredTask- See Also:
-
DEFAULT_DEFERRED_URL
The URL the DeferredTask servlet is mapped to by default.- See Also:
-
-
Method Details
-
getCurrentServlet
public static jakarta.servlet.http.HttpServlet getCurrentServlet()Returns theHttpServletinstance for the current running deferred task for the current thread ornullif there is no current deferred task active for this thread. -
getCurrentRequest
public static jakarta.servlet.http.HttpServletRequest getCurrentRequest()Returns theHttpServletRequestinstance for the current running deferred task for the current thread ornullif there is no current deferred task active for this thread. -
getCurrentResponse
public static jakarta.servlet.http.HttpServletResponse getCurrentResponse()Returns theHttpServletResponseinstance for the current running deferred task for the current thread ornullif there is no current deferred task active for this thread. -
setDoNotRetry
public static void setDoNotRetry(boolean value) Sets the action on task failure. Normally when an exception is thrown, the task will be retried, however ifsetDoNotRetryis set totrue, the task will not be retried. -
markForRetry
public static void markForRetry()Request a retry of this task, even if an exception was not thrown. If an exception was thrown andsetDoNotRetry(boolean)is set totruethe request will not be retried.
-