Class RequestPayloadTooLargeException

java.lang.Object
java.lang.Throwable
java.lang.Exception
java.io.IOException
java.net.MalformedURLException
com.google.appengine.api.urlfetch.RequestPayloadTooLargeException
All Implemented Interfaces:
Serializable

public class RequestPayloadTooLargeException extends MalformedURLException
RequestPayloadTooLargeException is thrown when the payload of a URLFetchService request is too large.

This is a subclass of MalformedURLException for backwards compatibility as it is thrown in places where MalformedURLException was thrown previously.

See Also:
  • Constructor Details

    • RequestPayloadTooLargeException

      public RequestPayloadTooLargeException(String url)