Uses of Class
com.google.appengine.api.urlfetch.HTTPHeader
Packages that use HTTPHeader
Package
Description
Provides a service to make HTTP/S requests of other servers on the internet.
-
Uses of HTTPHeader in com.google.appengine.api.urlfetch
Methods in com.google.appengine.api.urlfetch that return types with arguments of type HTTPHeaderModifier and TypeMethodDescriptionHTTPRequest.getHeaders()Returns an immutableListofHTTPHeaderobjects that have been added to this request.HTTPResponse.getHeaders()Returns aListof HTTP response headers that were returned by the remote server.HTTPResponse.getHeadersUncombined()Returns aListof HTTP response headers that were returned by the remote server.Methods in com.google.appengine.api.urlfetch with parameters of type HTTPHeaderModifier and TypeMethodDescriptionvoidHTTPRequest.addHeader(HTTPHeader header) Addsheaderto this request.voidHTTPRequest.setHeader(HTTPHeader header) Sets anHTTPHeaderfor this request.Constructor parameters in com.google.appengine.api.urlfetch with type arguments of type HTTPHeaderModifierConstructorDescriptionHTTPResponse(int responseCode, byte @Nullable [] content, @Nullable URL finalUrl, List<HTTPHeader> headers) Construct an HTTPResponse object.