Uses of Annotation Interface
com.google.apphosting.api.AppEngineInternal
Packages that use AppEngineInternal
Package
Description
Provides a service for indexing documents and retrieving them using search queries.
Packages with annotations of type AppEngineInternal
Package
Description
-
Uses of AppEngineInternal in com.google.appengine.api.datastore
Classes in com.google.appengine.api.datastore with annotations of type AppEngineInternalModifier and TypeClassDescriptionfinal classAn AsyncDatastoreService implementation that is pinned to a specific appId and namesapce.final classStatic utilities for working with composite indexes.final classInternal class that provides utility methods for extendable entity objects.final classUtilities for working withFuturesin the synchronous datastore api.classHelper class to translate betweenIndextoOnestoreEntity.Index.final classTransactionHelperenables the task queue API to serialize a datastore transaction without knowing the details of how it is implemented. -
Uses of AppEngineInternal in com.google.appengine.api.search
Classes in com.google.appengine.api.search with annotations of type AppEngineInternalModifier and TypeClassDescriptionfinal classBuildsSearchServiceinstances that are pinned to a specific application and namespace regardless of the "current" appId provided byApiProxy.getCurrentEnvironment().getAppId()and the "current" namespace provided byNamespaceManager.get().final classA utility class that centralizes processing of dates.final classCollection of utility methods for SearchServicePb.RequestStatus. -
Uses of AppEngineInternal in com.google.appengine.api.search.checkers
Classes in com.google.appengine.api.search.checkers with annotations of type AppEngineInternalModifier and TypeClassDescriptionfinal classProvides checks for Facet names and values: atom or number.final classProvides checks for faceted search related query options.