Package com.google.appengine.api
Interface EnvironmentProvider
public interface EnvironmentProvider
An interface for providing environment variables.
-
Method Summary
-
Method Details
-
getenv
Gets the value of the specified environment variable.- Parameters:
name- the name of the environment variable- Returns:
- the string value of the variable, or
nullif the variable is not defined
-
getenv
Gets the value of the specified environment variable, returning a default value if the variable is not defined.- Parameters:
name- the name of the environment variabledefaultValue- the default value to return- Returns:
- the string value of the variable, or the default value if the variable is not defined
-