Package com.google.appengine.api.log
Class AppLogLine
java.lang.Object
com.google.appengine.api.log.AppLogLine
- All Implemented Interfaces:
Serializable
An AppLogLine contains all the information for a single application
log. Specifically, this information is: (1) the time at which the logged
event occurred, (2) the level that the event was logged at, and (3) the
message associated with this event. AppLogLines may be inserted by the user
via logging frameworks, or by App Engine itself if we wish to alert the user
that certain events have occurred.
- See Also:
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanlonginthashCode()voidsetLogLevel(LogService.LogLevel logLevel) voidsetLogMessage(String logMessage) voidsetTimeUsec(long timeUsec) toString()
-
Constructor Details
-
AppLogLine
public AppLogLine()Default zero-argument constructor that creates an AppLogLine.
-
-
Method Details