Package com.google.appengine.api.log
Class LogQuery.Builder
java.lang.Object
com.google.appengine.api.log.LogQuery.Builder
- Enclosing class:
LogQuery
Contains static creation methods for
LogQuery.-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic LogQuerywithBatchSize(int batchSize) Create aLogQuerywith the given batch size.static LogQueryHelper method for creating aLogQueryinstance with default values.static LogQuerywithEndTimeMillis(long endTimeMillis) Create aLogQuerywith the given end time.static LogQuerywithEndTimeUsec(long endTimeUsec) Create aLogQuerywith the given end time.static LogQuerywithIncludeAppLogs(boolean includeAppLogs) Create aLogQuerywith include application logs set.static LogQuerywithIncludeIncomplete(boolean includeIncomplete) Create aLogQuerywith the given include incomplete setting.static LogQuerywithMajorVersionIds(List<String> versionIds) Create aLogQuerywith the given major version IDs.static LogQuerywithMinLogLevel(LogService.LogLevel minLogLevel) Create aLogQuerywith the given minimum log level.static LogQuerywithOffset(String offset) Create aLogQuerywith the given offset.static LogQuerywithRequestIds(List<String> requestIds) Create aLogQuerywith the given request IDs.static LogQuerywithStartTimeMillis(long startTimeMillis) Create aLogQuerywith the given start time.static LogQuerywithStartTimeUsec(long startTimeUsec) Create aLogQuerywith the given start time.static LogQuerywithVersions(List<LogQuery.Version> versions) Create aLogQuerywith the givenLogQuery.Versionvalues.
-
Constructor Details
-
Builder
public Builder()
-
-
Method Details
-
withOffset
Create aLogQuerywith the given offset. Shorthand forLogQuery.Builder.withDefaults().offset(offset);. Please read theLogQueryclass javadoc for an explanation of how offsets are used.- Parameters:
offset- the offset to use.- Returns:
- The newly created LogQuery instance.
-
withStartTimeMillis
Create aLogQuerywith the given start time. Shorthand forLogQuery.Builder.withDefaults().startTimeMillis(startTimeMillis);. Please read theLogQueryclass javadoc for an explanation of how start time is used.- Parameters:
startTimeMillis- the start time to use, in milliseconds.- Returns:
- The newly created LogQuery instance.
-
withStartTimeUsec
Create aLogQuerywith the given start time. Shorthand forLogQuery.Builder.withDefaults().startTimeUsec(startTimeUsec);. Please read theLogQueryclass javadoc for an explanation of how start time is used.- Parameters:
startTimeUsec- the start time to use, in microseconds.- Returns:
- The newly created LogQuery instance.
-
withEndTimeMillis
Create aLogQuerywith the given end time. Shorthand forLogQuery.Builder.withDefaults().endTimeMillis(endTimeMillis);. Please read theLogQueryclass javadoc for an explanation of how end time is used.- Parameters:
endTimeMillis- the end time to use, in milliseconds.- Returns:
- The newly created LogQuery instance.
-
withEndTimeUsec
Create aLogQuerywith the given end time. Shorthand forLogQuery.Builder.withDefaults().endTimeUsec(endTimeUsec);. Please read theLogQueryclass javadoc for an explanation of how end time is used.- Parameters:
endTimeUsec- the start time to use, in microseconds.- Returns:
- The newly created LogQuery instance.
-
withBatchSize
Create aLogQuerywith the given batch size. Shorthand forLogQuery.Builder.withDefaults().batchSize(batchSize);. Please read theLogQueryclass javadoc for an explanation of how batch size is used.- Parameters:
batchSize- the batch size to set.- Returns:
- The newly created LogQuery instance.
-
withMinLogLevel
Create aLogQuerywith the given minimum log level. Shorthand forLogQuery.Builder.withDefaults().minLogLevel(minLogLevel);. Please read theLogQueryclass javadoc for an explanation of how minimum log level is used.- Parameters:
minLogLevel- the minimum log level to set.- Returns:
- The newly created LogQuery instance.
-
withIncludeIncomplete
Create aLogQuerywith the given include incomplete setting. Shorthand forLogQuery.Builder.withDefaults().includeIncomplete(includeIncomplete);. Please read theLogQueryclass javadoc for an explanation of how include incomplete is used.- Parameters:
includeIncomplete- the inclusion value to set.- Returns:
- The newly created LogQuery instance.
-
withIncludeAppLogs
Create aLogQuerywith include application logs set. Shorthand forLogQuery.Builder.withDefaults().includeAppLogs(includeAppLogs);. Please read theLogQueryclass javadoc for an explanation of the include application logs setting.- Parameters:
includeAppLogs- the inclusion value to set.- Returns:
- The newly created LogQuery instance.
-
withMajorVersionIds
Create aLogQuerywith the given major version IDs. Shorthand forLogQuery.Builder.withDefaults().majorVersionIds(versionIds);. Please read theLogQueryclass javadoc for an explanation of how the list of major version ids is used.- Parameters:
versionIds- the major version id list to set.- Returns:
- The newly created LogQuery instance.
-
withVersions
Create aLogQuerywith the givenLogQuery.Versionvalues. Shorthand forLogQuery.Builder.withDefaults().versions(versions);. Please read theLogQueryclass javadoc for usage information.- Parameters:
versions- the list to set.- Returns:
- The newly created LogQuery instance.
-
withRequestIds
Create aLogQuerywith the given request IDs. Shorthand forLogQuery.Builder.withDefaults().requestIds(requestIds);. See theLogQueryclass javadoc for an explanation of how the list of request ids is used.- Parameters:
requestIds- the request id list to set.- Returns:
- The newly created LogQuery instance.
- Since:
- App Engine 1.7.4.
-
withDefaults
-