Package com.google.appengine.api.search
Class SortExpression
java.lang.Object
com.google.appengine.api.search.SortExpression
Sorting specification for a single dimension. Multi-dimensional sorting
is supported by a collection of SortExpressions.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classA builder that constructsSortExpressions.static enumThe direction search results are sorted by, either ascending or descending. -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final StringThe expression to be used if you wish to sort by document id fieldDocument.getId().static final StringThe expression to be used if you wish to sort by language code associated with the locale fieldDocument.getLocale().static final StringThe expression to be used if you wish to sort by rank field.static final StringThe expression to be used if you wish to sort by document score.static final StringThe expression to be used if you wish to sort by seconds since EPOCH that the document was written. -
Method Summary
Modifier and TypeMethodDescriptionstatic SortExpression.BuilderCreates and returns a SortExpression Builder.toString()
-
Field Details
-
DOCUMENT_ID_FIELD_NAME
The expression to be used if you wish to sort by document id fieldDocument.getId(). You need to create a sort expression asSortExpression expr = SortExpression.newBuilder() .setExpression(SortExpression.DOCUMENT_ID_FIELD_NAME) .setDefaultValue("") .build();- See Also:
-
LANGUAGE_FIELD_NAME
The expression to be used if you wish to sort by language code associated with the locale fieldDocument.getLocale(). You need to create a sort expression asSortExpression expr = SortExpression.newBuilder() .setExpression(SortExpression.LANGUAGE_FIELD_NAME) .setDefaultValue("") .build();- See Also:
-
RANK_FIELD_NAME
The expression to be used if you wish to sort by rank field. By default, results are sorted in descending value of rank. To sort in ascending order, you need to create a sort expression asSortExpression expr = SortExpression.newBuilder() .setExpression(SortExpression.RANK_FIELD_NAME) .setDirection(SortExpression.SortDirection.ASCENDING) .setDefaultValueNumeric(0) .build();- See Also:
-
SCORE_FIELD_NAME
The expression to be used if you wish to sort by document score. You need to create a sort expression asSortExpression expr = SortExpression.newBuilder() .setExpression(String.format( "%s + rating * 0.01", SortExpression.SCORE_FIELD_NAME)) .setDirection(SortExpression.SortDirection.DESCENDING) .setDefaultValueNumeric(0) .build();- See Also:
-
TIMESTAMP_FIELD_NAME
The expression to be used if you wish to sort by seconds since EPOCH that the document was written. You need to create a sort expression asSortExpression expr = SortExpression.newBuilder() .setExpression(SortExpression.TIMESTAMP_FIELD_NAME) .setDefaultValueNumeric(0) .build();- See Also:
-
-
Method Details
-
getExpression
- Returns:
- the expression to evaluate for each document and sort by
-
getDirection
- Returns:
- the direction to sort the search results in
-
getDefaultValue
- Returns:
- the default value for the field. Can be null
-
getDefaultValueNumeric
- Returns:
- the default numeric value for the field. Can be null
-
getDefaultValueDate
- Returns:
- the default date value for the field. Can be null
-
newBuilder
Creates and returns a SortExpression Builder.- Returns:
- a new
SortExpression.Builder. Set the parameters for the sort specification on the Builder, and use theSortExpression.Builder.build()method to create a concrete instance of SortExpression
-
toString
-