Class FetchOptions.Builder
java.lang.Object
com.google.appengine.api.urlfetch.FetchOptions.Builder
- Enclosing class:
FetchOptions
Contains static creation methods for
FetchOptions.-
Method Summary
Modifier and TypeMethodDescriptionstatic FetchOptionsCreate aFetchOptionsthat allows truncation of the response.static FetchOptionsCreate aFetchOptionsthat disallows truncation of the response.static FetchOptionsCreate aFetchOptionsthat does not follow redirects.static FetchOptionsCreate aFetchOptionsthat does not perform SSL certificate validation.static FetchOptionsCreate aFetchOptionsthat follows redirects.static FetchOptionsCreate aFetchOptionsthat performs SSL certificate validation.static FetchOptionswithDeadline(double deadline) Create aFetchOptionswith the specified deadline.static FetchOptionsHelper method for creating aFetchOptionsinstance with default values.
-
Method Details
-
allowTruncate
Create aFetchOptionsthat allows truncation of the response. Shorthand forFetchOptions.withDefaults().allowTruncate();. Please read theFetchOptionsclass javadoc for an explanation of how response truncating works.- Returns:
- The newly created FetchOptions instance.
-
disallowTruncate
Create aFetchOptionsthat disallows truncation of the response. Shorthand forFetchOptions.withDefaults().disallowTruncate();. Please read theFetchOptionsclass javadoc for an explanation of how esponse truncating works.- Returns:
- The newly created FetchOptions instance.
-
followRedirects
Create aFetchOptionsthat follows redirects. Shorthand forFetchOptions.withDefaults().followRedirects();. Please read theFetchOptionsclass javadoc for an explanation of how redirection following works.- Returns:
- The newly created FetchOptions instance.
-
doNotFollowRedirects
Create aFetchOptionsthat does not follow redirects. Shorthand forFetchOptions.withDefaults().doNotFollowRedirects();. Please read theFetchOptionsclass javadoc for an explanation of how redirection following works.- Returns:
- The newly created FetchOptions instance.
-
validateCertificate
Create aFetchOptionsthat performs SSL certificate validation. Shorthand forFetchOptions.withDefaults().validateCertificate();. Please read theFetchOptionsclass javadoc for an explanation of how certificate validation works.- Returns:
- The newly created FetchOptions instance.
-
doNotValidateCertificate
Create aFetchOptionsthat does not perform SSL certificate validation. Shorthand forFetchOptions.withDefaults().doNotValidateCertificate();. Please read theFetchOptionsclass javadoc for an explanation of how certificate validation works.- Returns:
- The newly created FetchOptions instance.
-
withDeadline
Create aFetchOptionswith the specified deadline. Shorthand forFetchOptions.withDefaults().setDeadline(deadline);.- Returns:
- The newly created FetchOptions instance.
-
withDefaults
Helper method for creating aFetchOptionsinstance with default values.- See Also:
-