Package com.google.apphosting.api
Annotation Interface AppEngineInternal
Annotation that marks a package or class as internal to App Engine. When
applied to package, all subpackages are also considered to be internal. User
code cannot safely depend on any class with this annotation or any class
belonging to a package or a parent package with this annotation.
-
Optional Element Summary
Optional Elements
-
Element Details
-
message
String message- Returns:
- A custom message to be printed when an unsafe reference to an internal class is detected.
- Default:
""
-